@@ -3,9 +3,12 @@
 namespace Icinga\Module\Businessprocess\Modification;
 
 use Icinga\Module\Businessprocess\BpConfig;
+use Icinga\Module\Businessprocess\Common\Sort;
 
 class NodeApplyManualOrderAction extends NodeAction
 {
+    use Sort;
+
     public function appliesTo(BpConfig $config)
     {
         return $config->getMetadata()->get('ManualOrder') !== 'yes';
@@ -20,7 +23,10 @@ class NodeApplyManualOrderAction extends NodeAction
             }
 
             if ($node->hasChildren()) {
-                $node->setChildNames($node->getChildNames());
+                $node->setChildNames(array_keys(
+                    $this->setSort('display_name asc')
+                        ->sort($node->getChildren())
+                ));
             }
         }
 
