@@ -3,9 +3,12 @@
 namespace Icinga\Module\Businessprocess\Modification;
 
 use Icinga\Module\Businessprocess\BpConfig;
+use Icinga\Module\Businessprocess\Common\Sort;
 
 class NodeCopyAction extends NodeAction
 {
+    use Sort;
+
     /**
      * @param BpConfig $config
      * @return bool
@@ -31,9 +34,15 @@ class NodeCopyAction extends NodeAction
     public function applyTo(BpConfig $config)
     {
         $name = $this->getNodeName();
-        $rootNodes = $config->getRootNodes();
+
+        $display = 1;
+        if ($config->getMetadata()->isManuallyOrdered()) {
+            $rootNodes = self::applyManualSorting($config->getRootNodes());
+            $display = end($rootNodes)->getDisplay() + 1;
+        }
+
         $config->addRootNode($name)
             ->getBpNode($name)
-            ->setDisplay(end($rootNodes)->getDisplay() + 1);
+            ->setDisplay($display);
     }
 }
