@@ -3,6 +3,8 @@
 namespace Icinga\Module\Businessprocess\Modification;
 
 use Icinga\Module\Businessprocess\BpConfig;
+use Icinga\Module\Businessprocess\BpNode;
+use Icinga\Module\Businessprocess\Node;
 
 /**
  * NodeRemoveAction
@@ -64,21 +66,30 @@ class NodeRemoveAction extends NodeAction
     {
         $name = $this->getNodeName();
         $parentName = $this->getParentName();
+        $node = $config->getNode($name);
+
+        /** @var ?BpNode $parentBpNode */
+        $parentBpNode = $parentName ? $config->getNode($parentName) : null;
+        $this->updateStateOverrides($node, $parentBpNode);
+
         if ($parentName === null) {
-            $oldDisplay = $config->getBpNode($name)->getDisplay();
-            $config->removeNode($name);
-            if ($config->getMetadata()->isManuallyOrdered()) {
-                foreach ($config->getRootNodes() as $_ => $node) {
-                    $nodeDisplay = $node->getDisplay();
-                    if ($nodeDisplay > $oldDisplay) {
-                        $node->setDisplay($node->getDisplay() - 1);
-                    } elseif ($nodeDisplay === $oldDisplay) {
-                        break;  // Stop immediately to not make things worse ;)
+            if (! $config->hasBpNode($name)) {
+                $config->removeNode($name);
+            } else {
+                $oldDisplay = $config->getBpNode($name)->getDisplay();
+                $config->removeNode($name);
+                if ($config->getMetadata()->isManuallyOrdered()) {
+                    foreach ($config->getRootNodes() as $_ => $node) {
+                        $nodeDisplay = $node->getDisplay();
+                        if ($nodeDisplay > $oldDisplay) {
+                            $node->setDisplay($node->getDisplay() - 1);
+                        } elseif ($nodeDisplay === $oldDisplay) {
+                            break;  // Stop immediately to not make things worse ;)
+                        }
                     }
                 }
             }
         } else {
-            $node = $config->getNode($name);
             $parent = $config->getBpNode($parentName);
             $parent->removeChild($name);
             $node->removeParent($parentName);
@@ -87,4 +98,28 @@ class NodeRemoveAction extends NodeAction
             }
         }
     }
+
+    /**
+     * Update state overrides
+     *
+     * @param Node $node
+     * @param BpNode|null $nodeParent
+     *
+     * @return void
+     */
+    private function updateStateOverrides(Node $node, ?BpNode $nodeParent): void
+    {
+        $parents = [];
+        if ($nodeParent !== null) {
+            $parents = [$nodeParent];
+        } else {
+            $parents = $node->getParents();
+        }
+
+        foreach ($parents as $parent) {
+            $parentStateOverrides = $parent->getStateOverrides();
+            unset($parentStateOverrides[$node->getName()]);
+            $parent->setStateOverrides($parentStateOverrides);
+        }
+    }
 }
