@@ -2,6 +2,7 @@
 
 namespace Icinga\Module\Businessprocess\ProvidedHook\Icingadb;
 
+use Icinga\Module\Businessprocess\BpConfig;
 use Icinga\Module\Icingadb\Hook\ServiceActionsHook;
 use Icinga\Module\Icingadb\Model\Service;
 use ipl\Web\Widget\Link;
@@ -16,9 +17,7 @@ class ServiceActions extends ServiceActionsHook
                 $label,
                 sprintf(
                     'businessprocess/node/impact?name=%s',
-                    rawurlencode(
-                        sprintf('%s;%s', $service->host->name, $service->name)
-                    )
+                    rawurlencode(BpConfig::joinNodeName($service->host->name, $service->name))
                 )
             )
         );
