@@ -9,10 +9,7 @@ use ipl\Html\Html;
 
 class TileRenderer extends Renderer
 {
-    /**
-     * @inheritdoc
-     */
-    public function render()
+    public function assemble()
     {
         $bp = $this->config;
         $nodesDiv = Html::tag(
@@ -20,7 +17,9 @@ class TileRenderer extends Renderer
             [
                 'class'                         => ['sortable', 'tiles', $this->howMany()],
                 'data-base-target'              => '_self',
-                'data-sortable-disabled'        => $this->isLocked() ? 'true' : 'false',
+                'data-sortable-disabled'        => $this->isLocked() || $this->appliesCustomSorting()
+                    ? 'true'
+                    : 'false',
                 'data-sortable-data-id-attr'    => 'id',
                 'data-sortable-direction'       => 'horizontal', // Otherwise movement is buggy on small lists
                 'data-csrf-token'               => CsrfToken::generate()
@@ -46,10 +45,8 @@ class TileRenderer extends Renderer
                     ->getAbsoluteUrl());
         }
 
-        $nodes = $this->getChildNodes();
-
         $path = $this->getCurrentPath();
-        foreach ($nodes as $name => $node) {
+        foreach ($this->sort($this->getChildNodes()) as $name => $node) {
             $this->add(new NodeTile($this, $node, $path));
         }
 
@@ -60,10 +57,8 @@ class TileRenderer extends Renderer
             }
         }
 
-        $nodesDiv->add($this->getContent());
-        $this->setContent($nodesDiv);
-
-        return parent::render();
+        $nodesDiv->addHtml(...$this->getContent());
+        $this->setHtmlContent($nodesDiv);
     }
 
     /**
