@@ -5,15 +5,18 @@ namespace Icinga\Module\Businessprocess\Web\Form;
 use Icinga\Application\Icinga;
 use Icinga\Application\Modules\Module;
 use ipl\Html\ValidHtml;
+use ipl\I18n\Translation;
 use Zend_Form;
 
 abstract class QuickBaseForm extends Zend_Form implements ValidHtml
 {
+    use Translation;
+
     /**
      * The Icinga module this form belongs to. Usually only set if the
      * form is initialized through the FormLoader
      *
-     * @var Module
+     * @var ?Module
      */
     protected $icingaModule;
 
@@ -123,7 +126,6 @@ abstract class QuickBaseForm extends Zend_Form implements ValidHtml
         }
 
         if (array_key_exists('icingaModule', $options)) {
-            /** @var Module icingaModule */
             $this->icingaModule = $options['icingaModule'];
             $this->icingaModuleName = $this->icingaModule->getName();
             unset($options['icingaModule']);
@@ -155,13 +157,4 @@ abstract class QuickBaseForm extends Zend_Form implements ValidHtml
 
         return strlen($value) === 0;
     }
-
-    public function translate($string)
-    {
-        if ($this->icingaModuleName === null) {
-            return t($string);
-        } else {
-            return mt($this->icingaModuleName, $string);
-        }
-    }
 }
