@@ -3,6 +3,8 @@
 namespace Icinga\Module\Businessprocess\Web;
 
 use Icinga\Application\Icinga;
+use Icinga\Application\Web;
+use Icinga\Web\Request;
 use Icinga\Web\Url as WebUrl;
 
 /**
@@ -14,13 +16,17 @@ use Icinga\Web\Url as WebUrl;
  */
 class Url extends WebUrl
 {
+    /**
+     * @return FakeRequest|Request
+     */
     protected static function getRequest()
     {
         $app = Icinga::app();
         if ($app->isCli()) {
             return new FakeRequest();
-        } else {
-            return $app->getRequest();
         }
+
+        /** @var Web $app */
+        return $app->getRequest();
     }
 }
