@@ -2,7 +2,9 @@
 
 $this->provideHook('monitoring/HostActions');
 $this->provideHook('monitoring/ServiceActions');
+$this->provideHook('monitoring/DetailviewExtension');
 $this->provideHook('icingadb/HostActions');
 $this->provideHook('icingadb/ServiceActions');
 $this->provideHook('icingadb/icingadbSupport');
+$this->provideHook('icingadb/ServiceDetailExtension');
 //$this->provideHook('director/shipConfigFiles');
