@@ -7,22 +7,20 @@ use Icinga\Module\Businessprocess\Test\BaseTestCase;
 
 class BpNodeTest extends BaseTestCase
 {
-    /**
-     * @expectedException \Icinga\Module\Businessprocess\Exception\NestingError
-     */
     public function testThrowsNestingErrorWhenCheckedForLoops()
     {
+        $this->expectException(\Icinga\Module\Businessprocess\Exception\NestingError::class);
+
         /** @var BpNode $bpNode */
         $bpNode = $this->makeLoop()->getNode('d');
         $bpNode->checkForLoops();
     }
 
-    /**
-     * @expectedExceptionMessage d -> a -> b -> c -> a
-     * @expectedException \Icinga\Module\Businessprocess\Exception\NestingError
-     */
     public function testNestingErrorReportsFullLoop()
     {
+        $this->expectException(\Icinga\Module\Businessprocess\Exception\NestingError::class);
+        $this->expectExceptionMessage('d -> a -> b -> c -> a');
+
         /** @var BpNode $bpNode */
         $bpNode = $this->makeLoop()->getNode('d');
         $bpNode->checkForLoops();
